//
//  GHMusicWidget.m
//  GameHub
//
//  Created by Evan Petousis on 4/12/12.
//  Copyright (c) 2012 1-Bit Software. All rights reserved.
//

#import "GHMusicWidget.h"

@implementation GHMusicWidget

- (id)initWithFrame:(NSRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        // Initialization code here.
        [nowPlayingField sizeToFit];
    }
    
    return self;
}

- (void)drawRect:(NSRect)dirtyRect
{
    // Drawing code here.
    iTunes = [SBApplication applicationWithBundleIdentifier:@"com.apple.iTunes"];
    Spotify = [SBApplication applicationWithBundleIdentifier:@"com.spotify.client"];
    if ([iTunes isRunning]&&[Spotify isRunning]) {
        NSLog(@"Two music sources running");
    }else{
    if ([iTunes isRunning]) {
        if ([iTunes playerState]==iTunesEPlSPaused) {
            playing = false;
        }else{
            playing=true;
        }
        if ([[iTunes currentTrack] name]) {
        nowPlayingString = [NSString stringWithFormat:@"%@ by %@",[[iTunes currentTrack] name], [[iTunes currentTrack] artist]];
        [nowPlayingField setStringValue:nowPlayingString];
        [self calcFontSizeToFitRect:[nowPlayingField frame]];
        }
    }
        if ([Spotify isRunning]) {
            if ([Spotify playerState]==SpotifyEPlSPaused) {
                playing = false;
            }else{
                playing=true;
            }
            if ([[Spotify currentTrack] name]) {
            nowPlayingString = [NSString stringWithFormat:@"%@ by %@",[[Spotify currentTrack] name], [[Spotify currentTrack] artist]];
            [nowPlayingField setStringValue:nowPlayingString];
            [self calcFontSizeToFitRect:[nowPlayingField frame]];
            }
        }
    }
    if (playing) {
        [playButton setImage:[NSImage imageNamed:@"pause.png"]];
    }else{
        [playButton setImage:[NSImage imageNamed:@"play.png"]];
    }
}

-(IBAction)playPause:(id)sender {
    if ([iTunes isRunning]&&[Spotify isRunning]) {
        NSLog(@"Two music sources running");
    }else{
    if ([iTunes isRunning]) {
    if (playing) {
        [iTunes pause];
        [playButton setImage:[NSImage imageNamed:@"play.png"]];
    }else{
        [iTunes playOnce:true];
        [playButton setImage:[NSImage imageNamed:@"pause.png"]];
    }
    }
        if ([Spotify isRunning]) {
            if (playing) {
                [Spotify pause];
                [playButton setImage:[NSImage imageNamed:@"play.png"]];
            }else{
                [Spotify play];
                [playButton setImage:[NSImage imageNamed:@"pause.png"]];
            }
        }
    }
    if (![iTunes isRunning]&&![Spotify isRunning]) {
        NSPoint newPoint = [self convertPoint:playButton.frame.origin toView:self.superview];
        NSRect newRect = NSMakeRect(newPoint.x, newPoint.y, playButton.frame.size.width, playButton.frame.size.height);
        sourceSelectOnPlayWindow = [[MAAttachedWindow alloc] initWithView:sourceSelectOnPlayView attachedToPoint:NSMakePoint(NSMidX(newRect), NSMinY(newRect)) inWindow:self.window atDistance:5];
        [sourceSelectOnPlayWindow setBackgroundColor:[NSColor colorWithCalibratedWhite:1.0 alpha:0.95]];
        [sourceSelectOnPlayWindow setLevel:25];
        [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(closeSourceWindow) name:NSWindowDidResignKeyNotification object:sourceSelectOnPlayWindow];
        [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(closeSourceWindow) name:NSWindowDidResignMainNotification object:sourceSelectOnPlayWindow];
        [sourceSelectOnPlayWindow makeKeyAndOrderFront:self];
    }
}

/*
 else{
 [iTunes run];
 [iTunes playOnce:true];
 [playButton setImage:[NSImage imageNamed:@"play.png"]];
 }
 */

-(IBAction)selectSource:(id)sender {
    [sourceSelectOnPlayWindow close];
    sourceSelectOnPlayWindow = nil;
    iTunes = [SBApplication applicationWithBundleIdentifier:@"com.apple.iTunes"];
    Spotify = [SBApplication applicationWithBundleIdentifier:@"com.spotify.client"];
    
    NSString *selectedSource = [[sourceSelectMatrix selectedCell] title];
    NSLog(@"selected : %@",selectedSource);
    if ([selectedSource isEqualToString:@"iTunes"]){
        [iTunes run];
        [self playPause:self];
    }else if ([selectedSource isEqualToString:@"Spotify"]){
        [Spotify activate];
        [self playPause:self];
    }
}

-(IBAction)nextTrack:(id)sender {
    if ([iTunes isRunning]&&[Spotify isRunning]) {
        NSLog(@"Two music sources running");
    }else{
        if ([iTunes isRunning]) {
    [iTunes nextTrack];
        }
        if ([Spotify isRunning]) {
            [Spotify nextTrack];
        }
    }
}

-(IBAction)prevTrack:(id)sender {
    if ([iTunes isRunning]&&[Spotify isRunning]) {
        NSLog(@"Two music sources running");
    }else{
        if ([iTunes isRunning]) {
            [iTunes previousTrack];
        }
        if ([Spotify isRunning]) {
            [Spotify previousTrack];
        }
    }
}

-(void)closeSourceWindow {
    [sourceSelectOnPlayWindow close];
    sourceSelectOnPlayWindow = nil;
}

-(void)calcFontSizeToFitRect:(NSRect)r {
    float targetWidth = r.size.width - 1;
    float targetHeight = r.size.height - 1;
    
    // the strategy is to start with a small font size and go larger until I'm larger than one of the target sizes
    int i;
    for (i=14; i<48; i++) {
        NSDictionary* attrs = [[NSDictionary alloc] initWithObjectsAndKeys:[NSFont fontWithName:@"Helvetica Neue UltraLight" size:i], NSFontAttributeName, nil];
        NSSize strSize = [nowPlayingString sizeWithAttributes:attrs];
        [attrs release];
        if (strSize.width > targetWidth || strSize.height > targetHeight) break;
    }
    [nowPlayingField setFont:[NSFont fontWithName:@"Helvetica Neue UltraLight" size:(i-1)]];
}

@end
