//
//  GHWeatherWidget.m
//  GameHub
//
//  Created by Evan Petousis on 1/12/12.
//  Copyright (c) 2012 1-Bit Software. All rights reserved.
//

#import "GHWeatherWidget.h"

@implementation GHWeatherWidget

- (id)initWithFrame:(NSRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        // Initialization code here.
    }
    
    return self;
}

-(void)awakeFromNib {
    [super awakeFromNib];
    weatherLabel = [[NSTextField alloc] initWithFrame:NSMakeRect(0, 0, self.frame.size.width, self.frame.size.height)];
    [weatherLabel setFont:[NSFont fontWithName:@"Helvetica Neue UltraLight" size:72]];
    [weatherLabel setAlignment:NSRightTextAlignment];
    [weatherLabel setTextColor:[NSColor whiteColor]];
    [weatherLabel setBezeled:NO];
    [weatherLabel setDrawsBackground:NO];
    [weatherLabel setEditable:NO];
    [weatherLabel setSelectable:NO];
    [self addSubview:weatherLabel positioned:NSWindowBelow relativeTo:self];
    
    [self updateWeather];
}

-(void)updateWeather {
    NSUserDefaults *userDefaults = [[NSUserDefaults alloc] init];
    weatherLocation = [[NSString alloc] init];
    weatherUnit = [[NSString alloc] init];
    if (userDefaults) {
        [userDefaults synchronize];
        weatherLocation = [userDefaults objectForKey:@"weatherLocation"];
        weatherUnit = [userDefaults objectForKey:@"weatherUnit"];
    }
    if ([weatherLocation length]>0) {
        NSString *stringURL = [NSString stringWithFormat:@"http://free.worldweatheronline.com/feed/weather.ashx?q=%@&format=json&key=5a8f782823031911120212",weatherLocation];
        NSURL  *url = [NSURL URLWithString:stringURL];
        NSData *weatherData = [NSData dataWithContentsOfURL:url];
        NSString *weatherString = [[NSString alloc] initWithData:weatherData encoding:NSUTF8StringEncoding];
        // Parse the string into JSON
        NSDictionary *json = [weatherString JSONValue];
        
        // Get the objects you want, e.g. output the second item's client id
        NSArray *items = [json valueForKeyPath:@"data.current_condition"];
        
        if ([weatherUnit length]>0){
            NSString *temperature = [[items objectAtIndex:0] objectForKey:[NSString stringWithFormat:@"temp_%@",weatherUnit]];
            if ([temperature length]>0) {
                NSLog(@"location and unit values found");
                [weatherLabel setStringValue:[NSString stringWithFormat:@"%@˚%@",[[items objectAtIndex:0] objectForKey:[NSString stringWithFormat:@"temp_%@",weatherUnit]],weatherUnit]];
            }else{
                NSLog(@"unit value found");
                [weatherLabel setStringValue:@"Weather"];
            }
        }else{
            NSString *temperature = [[[items objectAtIndex:0] objectForKey:@"temp_C"] stringValue];
            if ([temperature length]>0) {
                NSLog(@"location value found");
                [weatherLabel setStringValue:[NSString stringWithFormat:@"%@˚C",[[items objectAtIndex:0] objectForKey:@"temp_C"]]];
            }else{
                NSLog(@"no values found");
                [weatherLabel setStringValue:@"Weather"];
            }
        }
    }else{
        [weatherLabel setStringValue:@"Weather"];
    }
}

-(IBAction)changeSettings:(id)sender {
    if (!settingsWindow) {
        NSPoint newPoint = [self convertPoint:settingsButton.frame.origin toView:self.superview];
        NSRect newRect = NSMakeRect(newPoint.x, newPoint.y, settingsButton.frame.size.width, settingsButton.frame.size.height);
    settingsWindow = [[MAAttachedWindow alloc] initWithView:settingsView attachedToPoint:NSMakePoint(NSMidX(newRect), NSMinY(newRect)) inWindow:self.window atDistance:5];
    [settingsWindow setBackgroundColor:[NSColor colorWithCalibratedWhite:1.0 alpha:0.95]];
    [settingsWindow setLevel:25];
        NSUserDefaults *userDefaults = [[NSUserDefaults alloc] init];
        weatherLocation = [[NSString alloc] init];
        weatherUnit = [[NSString alloc] init];
        if (userDefaults) {
            [userDefaults synchronize];
            weatherLocation = [userDefaults objectForKey:@"weatherLocation"];
            weatherUnit = [userDefaults objectForKey:@"weatherUnit"];
        }
        NSLog(@"%@",weatherLocation);
        if (weatherLocation){
        [locationField setStringValue:[weatherLocation stringByReplacingOccurrencesOfString:@"%20" withString:@" "]];
        }
        if ([weatherUnit isEqualToString:@"C"]) {
            [unitSelector selectCellWithTag:1];
        }else{
            [unitSelector selectCellWithTag:0];
        }
        
        [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(closeSettingsWindow) name:NSWindowDidResignKeyNotification object:settingsWindow];
        [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(closeSettingsWindow) name:NSWindowDidResignMainNotification object:settingsWindow];
    [settingsWindow makeKeyAndOrderFront:self];
    }else{
        [settingsWindow close];
        settingsWindow=nil;
    }
}

-(IBAction)updateLocation:(id)sender {
    NSLog(@"Update location");
    NSTextField *tempField = sender;
    NSString *validURLString = [[tempField stringValue] stringByReplacingOccurrencesOfString:@" " withString:@"%20"];
    weatherLocation = validURLString;
    NSUserDefaults *userDefaults = [[NSUserDefaults alloc] init];
    if (userDefaults) {
        [userDefaults setObject:validURLString forKey:@"weatherLocation"];
        [userDefaults synchronize];
    }
    NSLog(@"valid url string : %@",weatherLocation);
    [self performSelectorInBackground:@selector(updateWeather) withObject:nil];
}

-(IBAction)updateUnit:(id)sender {
    NSLog(@"Update unit");
    NSUserDefaults *userDefaults = [[NSUserDefaults alloc] init];
    NSMatrix *tempMatrix = sender;
    if (userDefaults) {
        if ([[[tempMatrix selectedCell] title] isEqualToString:@"Farenheit"]) {
        [userDefaults setObject:@"F" forKey:@"weatherUnit"];
            weatherUnit = @"F";
            [userDefaults synchronize];
        }else if ([[[tempMatrix selectedCell] title] isEqualToString:@"Celcius"]){
            [userDefaults setObject:@"C" forKey:@"weatherUnit"];
            weatherUnit = @"C";
            [userDefaults synchronize];
        }
    }
    [self updateWeather];
}

-(void)closeSettingsWindow {
    [settingsWindow close];
    settingsWindow = nil;
}

- (void)drawRect:(NSRect)dirtyRect
{
    // Drawing code here.
}

@end
